/*
 * Copyright (c) 2007-2010 Sonatype, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.sonatype.sisu.assembler.gshell.internal;

import java.net.URI;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

@Singleton
public class LockedRepositoryRegistry
    implements RepositoryRegistry
{

    private static final String UPDATE_SITE_VAR = "updateSite";

    // TODO use gshell preferences to get the self update repository?
    private static final String UPDATE_SITE = "http://update.sonatype.org/content/repositories/mvnsh";

    private final RepositoryRegistry delegate;

    @Inject
    public LockedRepositoryRegistry( final RepositoryRegistry delegate )
    {
        assert delegate != null;
        this.delegate = delegate;
        if ( System.getProperty( UPDATE_SITE_VAR ) == null )
        {
            System.setProperty( UPDATE_SITE_VAR, UPDATE_SITE );
        }
    }

    public void add( final String repository )
    {
        delegate.add( repository );
    }

    public Collection<String> get()
    {
        if ( System.getProperty( UPDATE_SITE_VAR ) == null )
        {
            return delegate.get();
        }

        final List<String> repos = new ArrayList<String>();
        repos.add( System.getProperty( UPDATE_SITE_VAR ) );
        repos.addAll( delegate.get() );
        return Collections.unmodifiableList( repos );
    }

    public URI[] getAsURI()
    {
        if ( System.getProperty( UPDATE_SITE_VAR ) == null )
        {
            return delegate.getAsURI();
        }

        final URI[] uris = delegate.getAsURI();
        if ( uris.length == 0 )
        {
            return new URI[] { URI.create( System.getProperty( UPDATE_SITE_VAR ) ) };
        }
        final URI[] repos = new URI[uris.length + 1];
        repos[0] = URI.create( System.getProperty( UPDATE_SITE_VAR ) );
        System.arraycopy( uris, 0, repos, 1, uris.length );
        return repos;
    }

    public void remove( final String repository )
    {
        delegate.remove( repository );
    }

    public void removeAll()
    {
        delegate.removeAll();
    }

    public boolean isEmpty()
    {
        if ( System.getProperty( UPDATE_SITE_VAR ) == null )
        {
            return delegate.isEmpty();
        }

        return false;
    }

}
