/*
 * Copyright (c) 2007-2010 Sonatype, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.sonatype.sisu.assembler.gshell.internal;

import java.net.URI;
import java.util.List;

import org.sonatype.gshell.command.Command;
import org.sonatype.gshell.command.CommandContext;
import org.sonatype.gshell.command.support.CommandActionSupport;
import org.sonatype.gshell.util.cli2.Argument;
import org.sonatype.gshell.util.cli2.Option;

import com.google.inject.Inject;

@Command( name = "p2/repository/remove" )
public class RepositoryRemoveCommand
    extends CommandActionSupport
{

    @Argument( required = true )
    private URI uri;

    @Option( name = "a", longName = "all", override = true )
    private Boolean all = Boolean.FALSE;

    private final RepositoryRegistry repositoryRegistry;

    private final List<String> latestListed;

    @Inject
    public RepositoryRemoveCommand( final RepositoryRegistry repositoryRegistry,
                                    @RepositoryListCommand.Latest final List<String> latestListed )
    {
        assert repositoryRegistry != null;
        assert latestListed != null;
        this.latestListed = latestListed;
        this.repositoryRegistry = repositoryRegistry;
    }

    public Object execute( final CommandContext context )
        throws Exception
    {
        assert context != null;

        if ( all )
        {
            repositoryRegistry.removeAll();
        }
        else
        {
            try
            {
                final Integer idx = Integer.valueOf( uri.toASCIIString() );
                uri = new URI( latestListed.get( idx - 1 ) );
            }
            catch ( final Exception e )
            {
                // do nothing, value is not an index position
            }
            repositoryRegistry.remove( uri.toASCIIString() );
        }

        return Result.SUCCESS;
    }
}
